PROGRAM_NAME='CANON, RE-350, RS-232, BASIC, 10-96, WA'
(*   DATE:08/16/00    TIME:12:01:53    *)
(***********************************************************)
(* The following code block is provided as a guide to      *)
(* programming the device(s) listed above. This is a       *)
(* sample only, and will most likely require modification  *)
(* to be integrated into a master program.                 *)
(*                                                         *)
(* Device-specific protocols should be obtained directly   *)
(* from the equipment manufacturer to ensure compliance    *)
(* with the most current versions. Within the limits       *)
(* imposed by any non-disclosure agreements, AMX will      *)
(* provide protocols upon request.                         *)
(*                                                         *)
(* If further programming assistance is required, please   *)
(* contact your AMX customer support team.                 *)
(*                                                         *)
(*                                                         *)
(***********************************************************)
(* GENERAL FUNCTION LIST -                                 *)
(* SELECT DOCUMENT OR EXTERNAL VIDEO, LIGHTS ON/OFF, BACK-*)
(* LIGHT ON/OFF, OFF/ON LINE MODES, ZOOM, FOCUS AND COLOR  *)
(* COMMANDS.                                               *)
(*                                                         *)
(* NOTES -                                                 *)
(* THE CANON RE-350 VIDEO VISUALIZER IS CONTROLLED VIA     *)
(* RS-232 OR FRONT PANEL.   THE SELECTION OF COMMUNICATION,*)
(* AND ELECTRONIC SPEED AND IDENTIFICATION NUMBER CAN BE   *)
(* SELECTED ON THE REAR PANEL.                             *)
(* TO COMMUNICATE VIA RS-232 MODE, THE DEVICE MUST BE IN   *)
(* THE 'ON LINE' MODE.  WHILE IN THIS MODE, THE PHYSICAL   *)
(* POSITION OF EACH BUTTON IS DISREGARDED.                 *)
(*                                                         *)
(* COMMANDS  -                                             *)
(* THE LIGHTS ON WILL TOGGLE OFF THE BACKLIGHT ON AND VICE *)
(* VERSA.  THE REQUEST ZOOM COMMAND WILL RESPOND AFTER THE *)
(* ACCESS TO ZOOM COMMAND IS SENT.                         *)
(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE

DOC_CAMERA  = 2              (* RS232: CANON RE-350  9600,8,2 *)
PANEL       = 128            (* AMX PANEL *)
(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

DOC_CAM_BUFFER[100]          (* DOCUMENT CAMERA BUFFER *)
WB_CONTROL                   (* STATUS OF WHITE BALANCE KNOB *)
EXP_CONTROL                  (* STATUS OF EXPOSURE KNOB *)
DETAIL_CONTROL               (* STATUS OF DETAIL KNOB *)
AWB_CONTROL                  (* STATUS OF WHITE BALANCE WITH AUTO *)
ZOOM_POSITION                (* STATUS OF REQUESTED ZOOM POSITION *)
NAME[3]                      (* DEVICE NAME *)
ROM_VERSION[3]               (* DEVICE ROM VERSION *)

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE

(***********************************************************)
(*           SUBROUTINE DEFINITIONS GO BELOW               *)
(***********************************************************)


(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START

SEND_COMMAND DOC_CAMERA,'HSON'
SEND_COMMAND DOC_CAMERA,"'SET BAUD 9600,N,8,2'"

CREATE_BUFFER DOC_CAMERA,DOC_CAM_BUFFER
(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

(* SELECT INPUT SIGNAL *)
PUSH[PANEL,1]                (* SELECT DOCUMENT *)
  SEND_STRING DOC_CAMERA, "$10,$80,$50,$00,$00"

PUSH[PANEL,2]                (* SELECT EXTERNAL VIDEO *)
  SEND_STRING DOC_CAMERA, "$10,$80,$50,$01,$00"

(* LIGHT ON/OFF CONTROL *)
PUSH[PANEL,3]                (* LIGHTS ON *)
  SEND_STRING DOC_CAMERA, "$10,$80,$58,$00,$00"

PUSH[PANEL,4]                (* LIGHTS OFF *)
  SEND_STRING DOC_CAMERA, "$10,$80,$58,$01,$00"

PUSH[PANEL,5]                (* BACKLIGHT ON *)
  SEND_STRING DOC_CAMERA, "$10,$80,$59,$00,$00"

PUSH[PANEL,6]                (* BACKLIGHT OFF *)
  SEND_STRING DOC_CAMERA, "$10,$80,$59,$01 $00"

(* LED *)
PUSH[PANEL,7]                (* SET LED CONDITION NORMAL *)
  SEND_STRING DOC_CAMERA, "$10,$80,$68,$FF,$00"

(* COMMUNICATION REQUEST *)
PUSH[PANEL,11]               (* OFF LINE MODE *)
  SEND_STRING DOC_CAMERA, "$10,$80,$70,$00,$00"

PUSH[PANEL,12]               (* ON LINE MODE *)
  SEND_STRING DOC_CAMERA, "$10,$80,$70,$01,$00"

PUSH[PANEL,13]               (* ?????? SET TO NOTIFICATION MODE *)
  SEND_STRING DOC_CAMERA, "$10,$80,$70,$02,$00"

(* ZOOM *)
PUSH[PANEL,14]               (* HIGH SPEED WIDE ZOOM *)
  SEND_STRING DOC_CAMERA, "$10,$80,$00,$01 $00"

PUSH[PANEL,15]               (* HIGH SPEED TELE ZOOM *)
  SEND_STRING DOC_CAMERA, "$10,$80,$01,$01 $00"

RELEASE[PANEL,14]            (* STOP ZOOMING MOTOR *)
RELEASE[PANEL,15]
  SEND_STRING DOC_CAMERA, "$10,$80,$02,$00 $00"

PUSH[PANEL,16]               (* STEP FEED WIDE ZOOMING *)
  SEND_STRING DOC_CAMERA, "$10,$80,$00,$03 $00"

PUSH[PANEL,17]               (* STEP FEED TLEE ZOOMING *)
  SEND_STRING DOC_CAMERA, "$10,$80,$01,$03 $00"

PUSH[PANEL,18]               (* ACCESS TO POSITION *)
  SEND_STRING DOC_CAMERA, "$10,$80,$03,$00,$7F"

PUSH[PANEL,19]               (* REQUEST TO POSITION *)
{
  CLEAR_BUFFER DOC_CAM_BUFFER
  SEND_STRING DOC_CAMERA, "$10,$80,$04,$00,$00"
  WAIT_UNTIL(LENGTH_STRING(DOC_CAM_BUFFER))
    ZOOM_POSITION = DOC_CAM_BUFFER[5]
}

(* FOCUS *)
PUSH[PANEL,20]               (* OPERATE FOCUS (AUTO) *)
  SEND_STRING DOC_CAMERA, "$10,$80,$10,$00,$00"

PUSH[PANEL,21]               (* HIGH SPEED FOCUS NEAR *)
  SEND_STRING DOC_CAMERA, "$10,$80,$12,$01,$00"

PUSH[PANEL,22]               (* HIGH SPEED FOCUS FAR *)
  SEND_STRING DOC_CAMERA, "$10,$80,$13,$01,$00"

RELEASE[PANEL,21]            (* STOP THE AUTO FOCUS *)
RELEASE[PANEL,22]
  SEND_STRING DOC_CAMERA, "$10,$80,$14,$00,$00"

PUSH[PANEL,23]               (* STEP FEED FOCUS NEAR *)
  SEND_STRING DOC_CAMERA, "$10,$80,$12,$03,$00"

PUSH[PANEL,24]               (* STEP FEED FOCUS FAR *)
  SEND_STRING DOC_CAMERA, "$10,$80,$13,$03,$00"

(* COLOR *)
PUSH[PANEL,25]               (* OPERATE AUTO WHITE BALANCE *)
  SEND_STRING DOC_CAMERA, "$10,$80,$20,$00,$00"

PUSH[PANEL,26]               (* ACCESS TO A WB POSITION *)
  SEND_STRING DOC_CAMERA, "$10,$80,$22,$00,$00"

PUSH[PANEL,27]               (* ACCESS TO A WB POSITION *)
  SEND_STRING DOC_CAMERA, "$10,$80,$22,$00,$7F"

PUSH[PANEL,28]               (* ACCESS TO A WB POSITION *)
  SEND_STRING DOC_CAMERA, "$10,$80,$22,$00,$FF"

PUSH[PANEL,29]               (* ACCESS TO EXP *)
  SEND_STRING DOC_CAMERA, "$10,$80,$2A,$00,$00"

PUSH[PANEL,30]               (* ACCESS TO EXP *)
  SEND_STRING DOC_CAMERA, "$10,$80,$2A,$00,$A0"

PUSH[PANEL,31]               (* ACCESS TO EXP *)
  SEND_STRING DOC_CAMERA, "$10,$80,$2A,$00,$FF"

PUSH[PANEL,32]               (* ACCESS TO DETAIL (SHARPNESS) *)
  SEND_STRING DOC_CAMERA, "$10,$80,$30,$00,$00"

PUSH[PANEL,33]               (* ACCESS TO DETAIL (SHARPNESS) *)
  SEND_STRING DOC_CAMERA, "$10,$80,$30,$00,$7F"

PUSH[PANEL,34]               (* ACCESS TO DETAIL (SHARPNESS) *)
  SEND_STRING DOC_CAMERA, "$10,$80,$30,$00,$FF"

PUSH[PANEL,35]               (* SET POSITIVE MODE *)
  SEND_STRING DOC_CAMERA, "$10,$80,$38,$00,$00"

PUSH[PANEL,36]               (* SET NEGATIVE MODE *)
  SEND_STRING DOC_CAMERA, "$10,$80,$38,$01,$00"

PUSH[PANEL,37]               (* SET COLOR MODE *)
  SEND_STRING DOC_CAMERA, "$10,$80,$40,$00,$00"

PUSH[PANEL,38]               (* SET B/W *)
  SEND_STRING DOC_CAMERA, "$10,$80,$40,$01,$00"

(* STATUS REQUEST *)
PUSH[PANEL,39]               (* ??????? STATUS OF GROUP A *)
{
  CLEAR_BUFFER DOC_CAM_BUFFER
  SEND_STRING DOC_CAMERA, "$10,$80,$80,$00,$00"
}

PUSH[PANEL,40]               (* ???????STATUS OF GROUP B *)
{
  CLEAR_BUFFER DOC_CAM_BUFFER
  SEND_STRING DOC_CAMERA, "$10,$80,$80,$01,$00"
}

PUSH[PANEL,41]               (* ??????STATUS OF BUTTON *)
{
  CLEAR_BUFFER DOC_CAM_BUFFER
  SEND_STRING DOC_CAMERA, "$10,$80,$81,$00,$00"
}

PUSH[PANEL,42]               (* STATUS OF WB CONTROL KNOB *)
{
  CLEAR_BUFFER DOC_CAM_BUFFER
  SEND_STRING DOC_CAMERA, "$10,$80,$82,$00,$00"
  WAIT_UNTIL(LENGTH_STRING(DOC_CAM_BUFFER))
    WB_CONTROL = DOC_CAM_BUFFER[5]
}

PUSH[PANEL,43]               (* STATUS OF EXP CONTROL KNOB *)
{
  CLEAR_BUFFER DOC_CAM_BUFFER
  SEND_STRING DOC_CAMERA, "$10,$80,$82,$01,$00"
  WAIT_UNTIL(LENGTH_STRING(DOC_CAM_BUFFER))
    EXP_CONTROL = DOC_CAM_BUFFER[5]
}

PUSH[PANEL,44]               (* STATUS OF DETAIL CONTROL KNOB *)
{
  CLEAR_BUFFER DOC_CAM_BUFFER
  SEND_STRING DOC_CAMERA, "$10,$80,$82,$02,$00"
  WAIT_UNTIL(LENGTH_STRING(DOC_CAM_BUFFER))
    DETAIL_CONTROL = DOC_CAM_BUFFER[5]
}

PUSH[PANEL,45]               (* STATUS OF AWB RESULT *)
{
  CLEAR_BUFFER DOC_CAM_BUFFER
  SEND_STRING DOC_CAMERA, "$10,$80,$83,$00,$00"
  WAIT_UNTIL(LENGTH_STRING(DOC_CAM_BUFFER))
    AWB_CONTROL = DOC_CAM_BUFFER[5]
}

PUSH[PANEL,46]               (* NAME OF EQUIPMENT *)
{
  CLEAR_BUFFER DOC_CAM_BUFFER
  SEND_STRING DOC_CAMERA, "$10,$80,$88,$00,$00"
  WAIT_UNTIL(LENGTH_STRING(DOC_CAM_BUFFER))
  {
    NAME = MID_STRING(DOC_CAM_BUFFER,3,3)
  }
}

PUSH[PANEL,47]               (* VERSION OF ROM *)
{
  CLEAR_BUFFER DOC_CAM_BUFFER
  SEND_STRING DOC_CAMERA, "$10,$80,$88,$01,$00"
  WAIT_UNTIL(LENGTH_STRING(DOC_CAM_BUFFER))
    ROM_VERSION = MID_STRING(DOC_CAM_BUFFER,3,3)
}
(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)

